@@ -68,8 +68,6 @@ sub return_for_op {
 sub new {
     my ($cls,$options) = @_;
     my $o = $cls->SUPER::new($options);
-    bless $o, $cls;
-    return $o;
 }
 
 
@@ -81,7 +79,7 @@ foreach my $sub (qw(
     no strict 'refs';
     *{$sub} = sub {
         my $self = shift;
-        my $ret = $self->${\"SUPER::$sub"}(@_);
+        my $ret = $self->{\"SUPER::$sub"}(@_);
         $ret = return_for_op($ret, $sub);
         return $ret;
     };
@@ -89,7 +87,7 @@ foreach my $sub (qw(
     my $multi = "$sub\_multi";
     *{$multi} = sub {
         my $self = shift;
-        my $ret = $self->${\"SUPER::$multi"}(@_);
+        my $ret = $self->{\"SUPER::$multi"}(@_);
         return return_for_multi_wrap(\@_, $ret, $sub)
     };
 }
@@ -151,4 +149,4 @@ L<Cache::Memcached::libmemcached>
 Copyright (C) 2012 M. Nunberg
 
 You may use and distribute this software under the same terms, licensing, and
-conditions as perl itself.
+conditions as perl itself.
\ No newline at end of file
