@@ -8,10 +8,8 @@ typedef enum {
     PLCB_RETIDX_ERRNUM  = 1,
     PLCB_RETIDX_ERRSTR  = 2,
     PLCB_RETIDX_CAS     = 3,
-    
-    /*Extended Fields*/
-    PLCB_RETIDX_ORIGSIZE,
-    PLCB_RETIDX_KEYFLAGS,
+        
+    PLCB_RETIDX_MAX    
 } PLCB_ret_idx_t;
 
 #define plcb_ret_set_cas(obj, ret, cas) \
@@ -23,14 +21,6 @@ typedef enum {
         plcb_convert_retrieval(obj, value, nvalue, flags)); \
     plcb_ret_set_cas(obj, ret, &cas);
 
-/*not currently used*/
-
-#define plcb_ret_set_extfields(obj, ret, orig_len, orig_flags) \
-    if(obj->my_flags & PLCBf_RET_EXTENDED_FLAGS) { \
-        av_store(ret, PLCB_RETIDX_ORIGSIZE, newSVuv(orig_len)); \
-        av_store(ret, PLCB_RETIDX_KEYFLAGS, newSVuv(orig_flags)); \
-    }
-
 static inline void
 plcb_ret_set_numval(PLCB_t *obj, AV *ret, uint64_t value, uint64_t cas)
 {
@@ -51,9 +41,9 @@ plcb_ret_set_numval(PLCB_t *obj, AV *ret, uint64_t value, uint64_t cas)
 
 #define plcb_ret_set_err(obj, ret, err) \
     av_store(ret, PLCB_RETIDX_ERRNUM, newSViv(err)); \
-    if(err != LIBCOUCHBASE_SUCCESS) { \
+    if(err != LCB_SUCCESS) { \
         av_store(ret, PLCB_RETIDX_ERRSTR, \
-        newSVpv(libcouchbase_strerror(obj->instance, err), 0)); \
+        newSVpv(lcb_strerror(obj->instance, err), 0)); \
     }
 
 #define plcb_ret_blessed_rv(obj, ret) \
